//! Data structures for parsing JSON-RPC method parameters.

use serde::Deserialize;

// why do we have multiple structs when we could rather combine them by using
// `Option<String>` for some fields? simply because it's easier to handle the
// parsed parameters in our json-rpc server methods. we don't have to check
// if a given field is `Some` or `None` before passing it into the relevant
// function.

/// Network interface name.
#[derive(Debug, Deserialize)]
pub struct Iface {
    pub iface: String,
}

/// Network interface name and network identifier.
#[derive(Debug, Deserialize)]
pub struct IfaceId {
    pub iface: String,
    pub id: String,
}

/// Network interface name, network identifier and password.
#[derive(Debug, Deserialize)]
pub struct IfaceIdPass {
    pub iface: String,
    pub id: String,
    pub pass: String,
}

/// Network interface name and network SSID.
#[derive(Debug, Deserialize)]
pub struct IfaceSsid {
    pub iface: String,
    pub ssid: String,
}

/// Wireless interface (for which the WiFi credentials will be added), SSID
/// and password for a wireless access point.
#[derive(Debug, Deserialize)]
pub struct WiFi {
    pub iface: String,
    pub ssid: String,
    pub pass: String,
}

/// Wireles network interface and local Access Point network interface (the
/// interface on which we deloy or own AP).
#[derive(Debug, Deserialize)]
pub struct WlanAndAp {
    pub wlan_iface: String,
    pub ap_iface: String,
}
